JuliaElementType

Enum JuliaElementType 

pub enum JuliaElementType {
Show 78 variants Root, If, ElseIf, Else, For, While, Break, Continue, Function, End, Begin, Module, Using, Import, Export, Const, Local, Global, True, False, Nothing, Return, Plus, Minus, Star, Slash, Percent, Caret, Equal, NotEqual, LessThan, GreaterThan, LessEqual, GreaterEqual, Assign, PlusAssign, MinusAssign, StarAssign, SlashAssign, PercentAssign, CaretAssign, And, Or, Not, Colon, Dot, Range, Arrow, FatArrow, BitAnd, BitOr, BitXor, BitNot, LeftShift, RightShift, LeftParen, RightParen, LeftBracket, RightBracket, LeftBrace, RightBrace, Comma, Semicolon, IntegerLiteral, FloatLiteral, StringLiteral, CharLiteral, BooleanLiteral, NothingLiteral, Identifier, Call, ArgumentList, Comment, Whitespace, Newline, Eof, Error, Invalid,
}
Element types for the Julia language.

Variants



Root

Root node of the parse tree.



If

if keyword.



ElseIf

elseif keyword.



Else

else keyword.



For

for keyword.



While

while keyword.



Break

break keyword.



Continue

continue keyword.



Function

function keyword.



End

end keyword.



Begin

begin keyword.



Module

module keyword.



Using

using keyword.



Import

import keyword.



Export

export keyword.



Const

const keyword.



Local

local keyword.



Global

global keyword.



True

true keyword.



False

false keyword.



Nothing

nothing keyword.



Return

return keyword.



Plus

+ operator.



Minus

- operator.



Star

* operator.



Slash

/ operator.



Percent

% operator.



Caret

^ operator.



Equal

== operator.



NotEqual

!= operator.



LessThan

< operator.



GreaterThan

> operator.



LessEqual

<= operator.



GreaterEqual

>= operator.



Assign

= operator.



PlusAssign

+= operator.



MinusAssign

-= operator.



StarAssign

*= operator.



SlashAssign

/= operator.



PercentAssign

%= operator.



CaretAssign

^= operator.



And

&& operator.



Or

|| operator.



Not

! operator.



Colon

: operator.



Dot

. operator.



Range

: operator (range).



Arrow

-> operator.



FatArrow

=> operator.



BitAnd

& operator.



BitOr

| operator.



BitXor

xor or operator.



BitNot

~ operator.



LeftShift

<< operator.



RightShift

>> operator.



LeftParen

( delimiter.



RightParen

) delimiter.



LeftBracket

[ delimiter.



RightBracket

] delimiter.



LeftBrace

{ delimiter.



RightBrace

} delimiter.



Comma

, delimiter.



Semicolon

; delimiter.



IntegerLiteral

Integer literal.



FloatLiteral

Floating-point literal.



StringLiteral

String literal.



CharLiteral

Character literal.



BooleanLiteral

Boolean literal.



NothingLiteral

Nothing literal.



Identifier

Identifier.



Call

Function call.



ArgumentList

List of arguments.



Comment

Comment.



Whitespace

Whitespace.



Newline

Newline.



Eof

End of file.



Error

Error element.



Invalid

Invalid element.

Implementations

Source

impl JuliaElementType

pub fn as_str(&self) -> &'static str

Returns the string representation of the element type.

pub fn is_trivia(&self) -> bool

Returns true if the element is a trivia element (whitespace, comment, or newline).